'''
# ++++++++++++++++++++++++++++++++++++++++++++++++++++++++
# File: pay_constants.py
# Project: core.wecare.id
# File Created: Wednesday, 5th December 2018 12:07:34 am
#
# Author: Arif Dzikrullah
#         ardzix@hotmail.com>
#         https://github.com/ardzix/>
#
# Last Modified: Wednesday, 5th December 2018 12:07:34 am
# Modified By: arifdzikrullah (ardzix@hotmail.com>)
#
# Handcrafted and Made with Love
# Copyright - 2018 Wecare.Id, wecare.id
# ++++++++++++++++++++++++++++++++++++++++++++++++++++++++
'''


from decimal import Decimal
from django.utils.translation import gettext_lazy as _

BILL_STATUSES = (
    ('authorize', _('Authorized')),
    ('capture', _('Captured')),
    ('reviewed', _('Reviewed')),
    ('settlement', _('Settled')),
    ('deny', _('Denied')),
    ('pending', _('Pending')),
    ('cancel', _('Canceled')),
    ('refund', _('Refunded')),
    ('partial_refund', _('Partially Refunded')),
    ('chargeback', _('Charged Back')),
    ('partial_chargeback', _('Partially Charged Back')),
    ('expire', _('Expired')),
    ('failure', _('Failed'))
)
PAYMENT_STATUSES = BILL_STATUSES
INVOICE_STATUSES = BILL_STATUSES
WITHDRAW_STATUSES = (
    ('pending', _('Pending')),
    ('process', _('On Process')),
    ('paid', _('Paid')),
    ('not-paid', _('Not Paid')),
    ("expire", _("Expired")),
)
TOPUP_STATUSES = (
    ("pending", _("Pending")),
    ("approve", _("Approved")),
    ("success", _("Transfered")),
    ("deny", _("Denied")),
    ("fail", _("Failed")),
    ("expire", _("Expired")),
)
SUBSCRIPTION_CHARGE_METHOD = (
    (1, _("Credit Card")),
    (2, _("Wallet"))
)
BANK_CHOICES = (
    ("ANGLOMAS", "Anglomas International Bank"),
    ("BANGKOK", "Bangkok Bank"),
    ("AGRIS", "Bank Agris"),
    ("AGRONIAGA", "Bank BRI Agroniaga"),
    ("AMAR", "Bank Amar Indonesia (formerly Anglomas International Bank)"),
    ("ANDARA", "Bank Andara"),
    ("ANZ", "Bank ANZ Indonesia"),
    ("ARTA_NIAGA_KENCANA", "Bank Arta Niaga Kencana"),
    ("ARTHA", "Bank Artha Graha International"),
    ("ARTOS", "Bank Artos Indonesia"),
    ("BISNIS_INTERNASIONAL", "Bank Bisnis Internasional"),
    ("BJB", "Bank BJB"),
    ("BJB_SYR", "Bank BJB Syariah"),
    ("BNI_SYR", "Bank BNI Syariah"),
    ("BNP_PARIBAS", "Bank BNP Paribas"),
    ("BUKOPIN", "Bank Bukopin"),
    ("BUMI_ARTA", "Bank Bumi Arta"),
    ("CAPITAL", "Bank Capital Indonesia"),
    ("BCA", "Bank Central Asia (BCA)"),
    ("BCA_SYR", "Bank Central Asia (BCA) Syariah"),
    ("CHINATRUST", "Bank Chinatrust Indonesia"),
    ("CIMB", "Bank CIMB Niaga"),
    ("COMMONWEALTH", "Bank Commonwealth"),
    ("DANAMON", "Bank Danamon"),
    ("DANAMON_UUS", "Bank Danamon UUS"),
    ("DBS", "Bank DBS Indonesia"),
    ("DINAR_INDONESIA", "Bank Dinar Indonesia"),
    ("DKI", "Bank DKI"),
    ("DKI_UUS", "Bank DKI UUS"),
    ("FAMA", "Bank Fama International"),
    ("GANESHA", "Bank Ganesha"),
    ("HANA", "Bank Hana"),
    ("HARDA_INTERNASIONAL", "Bank Harda Internasional"),
    ("HIMPUNAN_SAUDARA", "Bank Himpunan Saudara 1906"),
    ("ICBC", "Bank ICBC Indonesia"),
    ("INA_PERDANA", "Bank Ina Perdania"),
    ("INDEX_SELINDO", "Bank Index Selindo"),
    ("JASA_JAKARTA", "Bank Jasa Jakarta"),
    ("JTRUST", "Bank JTrust Indonesia (formerly Bank Mutiara)"),
    ("KESEJAHTERAAN_EKONOMI", "Bank Kesejahteraan Ekonomi"),
    ("MANDIRI", "Bank Mandiri"),
    ("MASPION", "Bank Maspion Indonesia"),
    ("MAYAPADA", "Bank Mayapada International"),
    ("MAYBANK", "Bank Maybank"),
    ("MAYBANK_SYR", "Bank Maybank Syariah Indonesia"),
    ("MAYORA", "Bank Mayora"),
    ("MEGA", "Bank Mega"),
    ("MESTIKA_DHARMA", "Bank Mestika Dharma"),
    ("MITRA_NIAGA", "Bank Mitra Niaga"),
    ("MIZUHO", "Bank Mizuho Indonesia"),
    ("MNC_INTERNASIONAL", "Bank MNC Internasional"),
    ("MUAMALAT", "Bank Muamalat Indonesia"),
    ("MULTI_ARTA_SENTOSA", "Bank Multi Arta Sentosa"),
    ("NATIONALNOBU", "Bank Nationalnobu"),
    ("BNI", "Bank Negara Indonesia (BNI)"),
    ("NUSANTARA_PARAHYANGAN", "Bank Nusantara Parahyangan"),
    ("OCBC", "Bank OCBC NISP"),
    ("OCBC_UUS", "Bank OCBC NISP UUS"),
    ("BAML", "Bank of America Merill-Lynch"),
    ("BOC", "Bank of China (BOC)"),
    ("INDIA", "Bank of India Indonesia"),
    ("TOKYO", "Bank of Tokyo Mitsubishi UFJ"),
    ("OKE", "Bank Oke Indonesia (formerly Bank Andara)"),
    ("PANIN", "Bank Panin"),
    ("PANIN_SYR", "Bank Panin Syariah"),
    ("PERMATA", "Bank Permata"),
    ("PERMATA_UUS", "Bank Permata UUS"),
    ("QNB_INDONESIA", "Bank QNB Indonesia (formerly Bank QNB Kesawan)"),
    ("RABOBANK", "Bank Rabobank International Indonesia"),
    ("BRI", "Bank Rakyat Indonesia (BRI)"),
    ("RESONA", "Bank Resona Perdania"),
    ("ROYAL", "Bank Royal Indonesia"),
    ("SAHABAT_SAMPOERNA", "Bank Sahabat Sampoerna"),
    ("SBI_INDONESIA", "Bank SBI Indonesia"),
    ("SHINHAN", "Bank Shinhan Indonesia (formerly Bank Metro Express)"),
    ("SINARMAS", "Bank Sinarmas"),
    ("SINARMAS_UUS", "Bank Sinarmas UUS"),
    ("MITSUI", "Bank Sumitomo Mitsui Indonesia"),
    ("BRI_SYR", "Bank Syariah BRI"),
    ("BUKOPIN_SYR", "Bank Syariah Bukopin"),
    ("MANDIRI_SYR", "Bank Syariah Mandiri"),
    ("MEGA_SYR", "Bank Syariah Mega"),
    ("BTN", "Bank Tabungan Negara (BTN)"),
    ("BTN_UUS", "Bank Tabungan Negara (BTN) UUS"),
    ("TABUNGAN_PENSIUNAN_NASIONAL", "Bank Tabungan Pensiunan Nasional"),
    ("UOB", "Bank UOB Indonesia"),
    ("VICTORIA_INTERNASIONAL", "Bank Victoria Internasional"),
    ("VICTORIA_SYR", "Bank Victoria Syariah"),
    ("WOORI", "Bank Woori Indonesia"),
    ("WOORI_SAUDARA", "Bank Woori Saudara Indonesia 1906 (formerly Bank Himpunan Saudara and Bank Woori Indonesia)"),
    ("YUDHA_BHAKTI", "Bank Yudha Bhakti"),
    ("ACEH", "BPD Aceh"),
    ("ACEH_UUS", "BPD Aceh UUS"),
    ("BALI", "BPD Bali"),
    ("BANTEN", "BPD Banten (formerly Bank Pundi Indonesia)"),
    ("BENGKULU", "BPD Bengkulu"),
    ("DAERAH_ISTIMEWA", "BPD Daerah Istimewa Yogyakarta (DIY)"),
    ("DAERAH_ISTIMEWA_UUS", "BPD Daerah Istimewa Yogyakarta (DIY) UUS"),
    ("JAMBI", "BPD Jambi"),
    ("JAMBI_UUS", "BPD Jambi UUS"),
    ("JAWA_TENGAH", "BPD Jawa Tengah"),
    ("JAWA_TENGAH_UUS", "BPD Jawa Tengah UUS"),
    ("JAWA_TIMUR", "BPD Jawa Timur"),
    ("JAWA_TIMUR_UUS", "BPD Jawa Timur UUS"),
    ("KALIMANTAN_BARAT", "BPD Kalimantan Barat"),
    ("KALIMANTAN_BARAT_UUS", "BPD Kalimantan Barat UUS"),
    ("KALIMANTAN_SELATAN", "BPD Kalimantan Selatan"),
    ("KALIMANTAN_SELATAN_UUS", "BPD Kalimantan Selatan UUS"),
    ("KALIMANTAN_TENGAH", "BPD Kalimantan Tengah"),
    ("KALIMANTAN_TIMUR", "BPD Kalimantan Timur"),
    ("KALIMANTAN_TIMUR_UUS", "BPD Kalimantan Timur UUS"),
    ("LAMPUNG", "BPD Lampung"),
    ("MALUKU", "BPD Maluku"),
    ("NUSA_TENGGARA_BARAT", "BPD Nusa Tenggara Barat"),
    ("NUSA_TENGGARA_BARAT_UUS", "BPD Nusa Tenggara Barat UUS"),
    ("NUSA_TENGGARA_TIMUR", "BPD Nusa Tenggara Timur"),
    ("PAPUA", "BPD Papua"),
    ("RIAU_DAN_KEPRI", "BPD Riau Dan Kepri"),
    ("RIAU_DAN_KEPRI_UUS", "BPD Riau Dan Kepri UUS"),
    ("SULAWESI", "BPD Sulawesi Tengah"),
    ("SULAWESI_TENGGARA", "BPD Sulawesi Tenggara"),
    ("SULSELBAR", "BPD Sulselbar"),
    ("SULSELBAR_UUS", "BPD Sulselbar UUS"),
    ("SULUT", "BPD Sulut"),
    ("SUMATERA_BARAT", "BPD Sumatera Barat"),
    ("SUMATERA_BARAT_UUS", "BPD Sumatera Barat UUS"),
    ("SUMSEL_DAN_BABEL", "BPD Sumsel Dan Babel"),
    ("SUMSEL_DAN_BABEL_UUS", "BPD Sumsel Dan Babel UUS"),
    ("SUMUT", "BPD Sumut"),
    ("SUMUT_UUS", "BPD Sumut UUS"),
    ("BTPN_SYARIAH", "BTPN Syariah (formerly BTPN UUS and Bank Sahabat Purba Danarta)"),
    ("CENTRATAMA", "Centratama Nasional Bank"),
    ("CCB", "China Construction Bank Indonesia (formerly Bank Antar Daerah and Bank Windu Kentjana International)"),
    ("CITIBANK", "Citibank"),
    ("DEUTSCHE", "Deutsche Bank"),
    ("HSBC_UUS", "Hongkong and Shanghai Bank Corporation (HSBC) UUS"),
    ("HSBC", "HSBC Indonesia (formerly Bank Ekonomi Raharja)"),
    ("EXIMBANK", "Indonesia Eximbank (formerly Bank Ekspor Indonesia)"),
    ("JPMORGAN", "JP Morgan Chase Bank"),
    ("MANDIRI_TASPEN", "Mandiri Taspen Pos (formerly Bank Sinar Harapan Bali)"),
    ("PRIMA_MASTER", "Prima Master Bank"),
    ("RBS", "Royal Bank of Scotland (RBS)"),
    ("STANDARD_CHARTERED", "Standard Chartered Bank"),
)
